yakumo.nova.v2.flavor.Resource

Package yakumo :: Package nova :: Package v2 :: Module flavor :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for flavors in Compute API v2

Instance Methods | [hide private]
None |
add_project(self, project=None) Make a project accessible to the flavor | source code
None |
remove_project(self, project=None) Make a project accessible to the flavor | source code
[yakumo.project.Resource] |
list_project(self) Make a project accessible to the flavor | source code
str |
get_extra_spec(self, key=None) Get extra specs for a flavor | source code
None |
create_extra_spec(self, extra_spec=None) Create extra specs for a flavor | source code
None |
update_extra_spec(self, _kwargs=None, **kwargs) Update extra specs for a flavor | source code
None |
delete_extra_spec(self, key) Delete one key=value from extra specs | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `update`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### add_project(self, project=None) | source code
Make a project accessible to the flavor Parameters: `project` (yakumo.project.Resource) - Project (required) Returns: None

### remove_project(self, project=None) | source code
Make a project accessible to the flavor Parameters: `project` (yakumo.project.Resource) - Project (required) Returns: None

### list_project(self) | source code
Make a project accessible to the flavor Returns: [yakumo.project.Resource] Project list

### get_extra_spec(self, key=None) | source code
Get extra specs for a flavor Parameters: `key` (str) - key Returns: str value

### create_extra_spec(self, extra_spec=None) | source code
Create extra specs for a flavor Parameters: `extra_spec` (dict) - Extra specs Returns: None

### update_extra_spec(self, _kwargs=None, **kwargs) | source code
Update extra specs for a flavor Parameters: `extra_spec` (dict) - Extra specs Returns: None

### delete_extra_spec(self, key) | source code
Delete one key=value from extra specs Parameters: `key` (str) - Key Returns: None